# Tuitoy
v 1.0

## Table of Content
* [About](#about)
* [To do](#to-do)

## About

Terminal User Interface Toy
This is a library designed to make terminal application by drawing windows and components using python curses

## To do
[ ] - Complete a well documented README with descriptions of all the classes and functions allowing for users to create custom components by extending existing classes
